/************************************************
 * This is a class that runs the blowfish
 * 	algorithm and cuts the plaintext in pieces of
 * 	8 bytes each and passes it to Blowfish
 * 
 * @author Achilleas Tziazas
 * @author Ed Wolf
 *
 */
public class BlowfishProject {

	/**
	 * The main method
	 * 
	 * @param args
	 */
	public static void main (String args[]) {
		
		//Check to see if we have the correct number of arguments, and if the key is less than 448 bits.
        if (args.length != 3){
            System.err.println("Usage: java Project [key] [plaintext or ciphertext] [-e encrypt or -d decrypt]");
            System.exit(0);
        }
        
        //Check if the key is a multiple of 8 bits
        if(args[0].length()%2 != 0 || args[0].length() == 0) {
            System.err.println("ERROR: The key needs to be a multiple of 8-bits");
            System.err.println("Usage: java Project [key] [plaintext or ciphertext] [-e encrypt or -d decrypt]");
            System.exit(0);
        }//the key can be no longer than 448 bits
        else if(args[0].length() > 112){
            System.err.println("ERROR: The key needs to be less than 448-bits");
            System.err.println("Usage: java Project [hex key] [plaintext or ciphertext] [-e encrypt or -d decrypt]");
            System.exit(0);
        }
        
        //Encrypt the plaintext message.
        if (args[2].equals("-e") || args[2].equals("-E") ){
        	if (args[1].length() !=16){
        		System.err.println("ERROR: Only a 16 character string please");
                System.err.println("Usage: java Project [hex key] [plaintext or ciphertext] [-e encrypt or -d decrypt]");
                System.exit(0);
        	}
           // Make a Blowfish object
        	Blowfish bf = new Blowfish(args[0]);
        
        	/*
        	 * The code for variable length plaintext is not fully deeloped yet
        	 * 
        	int remainder = args[1].length() % 8; 
        	System.out.println("Remainder: " +remainder);
        	int multiply = args[1].length() / 8;
        	System.out.println("Multiply: " +multiply);
        	String ciphertext = "";
        	
        	for (int i = 0; i < multiply; i++)
        	{
        		System.out.println("*************" +args[1].substring(i,i+8));
        		ciphertext += bf.encrypt(args[1].substring(i,i+8));
        	}
        	
        	if (remainder != 0) {
        		int lastEncrypt = 8 - remainder;
        		String lastString = args[1].substring(multiply*8);
        		for (int i = 0 ; i < lastEncrypt; i++) {
        			lastString += "0";
        		}
        		ciphertext += bf.encrypt(lastString);
        	}*/
        	
        	String ciphertext = bf.encrypt(args[1].substring(0,8));
        	ciphertext += bf.encrypt(args[1].substring(8));
        	
        	System.out.println("The ciphertext is: " + ciphertext);
        	
        }
        //Decrypt the ciphertext message.
        else if (args[2].equals("-d") || args[2].equals("-D") ){
           Blowfish bf = new Blowfish(args[0]);
           String plaintext = bf.decrypt(args[1].substring(0, 16));
           plaintext += bf.decrypt(args[1].substring(16));
           
           System.out.println("The plaintext is: " + plaintext);
           
        }
        //Invalid command line arguments. Terminate the program.
        else{
            System.err.println("Usage: java Project [hex key <= 448 bits] [plaintext or ciphertext] [-e encrypt or -d decrypt]");
            System.exit(0);
        }
		
	}
	
	
}
